@@ -1,5 +1,5 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright (C) 2000, 2001 Edgar Denny (e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,10 +16,14 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-void gnutr_show_edit_food_dlg( void);
+void 
+gnutr_show_edit_food_dlg( char *, char *, char *, int);
 
-void on_gnutr_edit_food_msre_combo_entry_changed( GtkEditable *, gpointer);
+void 
+on_gnutr_edit_food_msre_combo_entry_changed( GtkEditable *, gpointer);
 
-void on_gnutr_edit_food_cancel_button_released( GtkButton *, gpointer);
+void 
+on_gnutr_edit_food_cancel_button_released( GtkButton *, gpointer);
 
-void on_gnutr_edit_food_ok_button_released( GtkButton *, gpointer);
+void 
+on_gnutr_edit_food_ok_button_released( GtkButton *, gpointer);
