@@ -1,5 +1,5 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright (C) 2000, 2001 Edgar Denny (e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,17 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
-void gnutr_show_search_result_dlg( GList *);
 
-void on_gnutr_srch_result_clist_select_row( GtkCList *, gint, gint, 
-		GdkEvent *, gpointer);
+void 
+gnutr_show_food_srch_res_dlg( GList *, gint);
 
-void on_gnutr_srch_result_sel_food_entry_changed( GtkEditable *, gpointer);
+void 
+on_gnutr_srch_result_cancel_button_released( GtkButton *, gpointer);
 
-void on_gnutr_srch_result_msre_combo_entry_changed( GtkEditable *, gpointer);
-
-void on_gnutr_srch_result_ok_button_released( GtkButton *, gpointer);
-
-void on_gnutr_srch_result_cancel_button_released( GtkButton *, gpointer);
-
-void gnutr_hide_srch_result_dialog( void);
+void 
+gnutr_hide_srch_result_dialog( void);
