@@ -1,5 +1,5 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright (C) 2000, 2001 Edgar Denny (e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,6 +16,5 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-gint on_idle_in_main( gpointer);
-
-GList *gnutr_ret_food_glist( void);
+void
+gnutr_startup( void);
