@@ -1,5 +1,5 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright (C) 2000, 2001 Edgar Denny (e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,21 +16,20 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <gnome.h>
 #include <glade/glade.h>
-
-#include "support.h"
-#include "recipe_win.h"
 #include "load_data.h"
+#include "gnutr_druid.h"
+#include "base_win.h"
 
-/* A minimalist main.c */
 gint
 main( int argc, char *argv[])
 {
-	GtkWidget *dummy = NULL;
+	gboolean exists1, exists2;
+	char *home, *fn;
 
 #ifdef ENABLE_NLS
 	bindtextdomain( PACKAGE, PACKAGE_LOCALE_DIR);
@@ -41,8 +40,23 @@ main( int argc, char *argv[])
 
 	glade_gnome_init();
 
-	/* this passes control to the progress bar. */
-	gtk_idle_add( on_idle_in_main, dummy);
+	home = g_get_home_dir();
+
+	/* check that a config file exists in .gnutrition */
+	fn = g_strconcat( home, "/.gnutrition/mysql_access.xml", NULL);
+	exists1 = g_file_test( fn, G_FILE_TEST_ISFILE);
+	g_free( fn);
+
+	fn = g_strconcat( home, "/.gnutrition/person_info.xml", NULL);
+	exists2 = g_file_test( fn, G_FILE_TEST_ISFILE);
+	g_free( fn);
+
+	if ( exists1 && exists2) {
+		gnutr_startup();
+		gnutr_show_base_win();
+	} else {
+		gnutr_show_druid_win();
+	}
 
 	gtk_main();
 
