@@ -1,5 +1,5 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright (C) 2000, 2001 Edgar Denny (e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,11 +17,16 @@
  */
 
 void
-display_nutrient_dialog( void);
+gnutr_show_nutr_comp_dlg( GList *, int);
+
+GtkWidget *
+gnutr_get_comp_notebook( void);
+
+GtkWidget *
+gnutr_get_comp_notebook_container( void);
 
 void
-gnutr_show_nutr_comp_dlg( void);
+gnutr_reset_nutr_comp( void);
 
 void
-on_ndlg_ok_button_released( GtkButton *button,
-		                    gpointer   user_data);
+gnutr_calc_nutr_comp( char *, char *, char *);
