@@ -1,5 +1,5 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright (C) 2000, 2001 Edgar Denny (e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -13,30 +13,23 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  
  */
 
-typedef struct Nutrition_s {
-	gfloat total[NO_NUTR];
-	gfloat pcnt_goal[NO_NUTR];
-	gfloat goal[NO_NUTR];
-} Nutrition_t;
+void
+gnutr_save_recipe( GList *, char *, char *, char *, int);
 
-typedef struct Recipe_s {
-	gchar *name;
-	gchar *no_serv;
-	gint no_ingredients;
-	gint selected_row;
-	GtkCList* ingredient_clist;
-	Nutrition_t *nutr;
-	gchar *file_name;
-} Recipe_t;
+void
+gnutr_delete_recipe( char *);
 
-gboolean 
-gnutr_read_recipe( gchar *, Recipe_t **, GList *);
+char *
+gnutr_check_recipe_exists( char *);
 
-gboolean 
-gnutr_write_recipe( gchar *, Recipe_t *);
+GHashTable *
+get_htbl_cat_desc_cat_no( void);
 
-Recipe_t *
-gnutr_ret_recipe( void);
+GHashTable *
+get_htbl_cat_no_cat_desc( void);
+
+GList *
+get_cat_desc_list( void);
