@@ -1,10 +1,10 @@
 /*  gnutrition - a nutrition and diet analysis program.
- *  Copyright (C) 2000 Edgar Denny (e.denny@ic.ac.uk)
+ *  Copyright( C) 2000, 2001 Edgar Denny( e.denny@ic.ac.uk)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * ( at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,26 +16,17 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-gchar *
-extract_column( gchar *, gint, gint);
+char *
+ftoa( float);
 
-gint
-text_match( gchar *, gchar *);
-
-gchar *
-ftoa( gfloat);
-
-gchar *
+char *
 itoa( int);
 
-gint
-empty_text( gchar *);
+int
+empty_text( char *);
 
-gint
-all_digits( gchar *);
-
-gboolean
-gnutr_file_test( gchar *);
+int
+all_digits( char *);
 
 void
-gnutr_dir_test( gchar *);
+gnutr_dir_test( char *);
